@@ -1,5 +1,6 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * dif.c: read/write sheets using a CSV encoding.
+ * dif.c: read/write sheets using a DIF encoding.
  *
  * Authors:
  *   Kevin Handy <kth@srv.net>
@@ -8,12 +9,14 @@
  *	Based on ff-csv code.
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 
 #include <cell.h>
 #include <sheet.h>
 #include <value.h>
+#include <numbers.h>
+#include <gutils.h>
 #include <goffice/app/io-context.h>
 #include <workbook-view.h>
 #include <workbook.h>
@@ -33,13 +36,14 @@ GNM_PLUGIN_MODULE_HEADER;
 void dif_file_open (GOFileOpener const *fo, IOContext *io_context,
                     WorkbookView *wbv, GsfInput *input);
 void dif_file_save (GOFileSaver const *fs, IOContext *io_context,
-                    WorkbookView const *wbv, GsfOutput *output);
+                    WorkbookView const *wbv, GsfOutput *out);
 
 typedef struct {
 	IOContext *io_context;
 
 	GsfInputTextline *input;
 	gint   line_no;
+	gsize  line_len;
 	gchar *line;
 
 	Sheet *sheet;
@@ -82,15 +86,15 @@ static gboolean
 dif_get_line (DifInputContext *ctxt)
 {
 	char *raw;
-
-	raw = gsf_input_textline_ascii_gets (ctxt->input);
-	if (!raw)
+	
+	if (NULL == (raw = gsf_input_textline_ascii_gets (ctxt->input)))
 		return FALSE;
 
 	g_free (ctxt->line);
-	ctxt->line =
-		g_convert_with_iconv (raw, -1, ctxt->converter, NULL, NULL, NULL);
+	ctxt->line = g_convert_with_iconv (raw, -1, ctxt->converter,
+					   NULL, &ctxt->line_len, NULL);
 
+	ctxt->line_no++;
 	return ctxt->line != NULL;
 }
 
@@ -154,50 +158,69 @@ dif_parse_data (DifInputContext *ctxt)
 {
 	gboolean too_many_rows = FALSE, too_many_columns = FALSE;
 	gint row = -1, col = 0;
+	gint val_type;
+	GnmCell *cell;
+	gchar *msg;
 
 	while (1) {
-		gint val_type;
-		GnmCell *cell;
-		gchar *msg;
-
 		if (!dif_get_line (ctxt))
 			return FALSE;
 
 		val_type = atoi (ctxt->line);
 		if (val_type == 0) {
-			gchar *comma;
-
-			(void) dif_get_line (ctxt);
-			if (col > SHEET_MAX_COLS) {
+			gchar const *comma = strchr (ctxt->line, ',');
+			if (comma == NULL)
+				gnm_io_warning (ctxt->io_context,
+						_("Syntax error at line %d. Ignoring."),
+						ctxt->line_no);
+			else if (col > SHEET_MAX_COLS) {
 				too_many_columns = TRUE;
-				continue;
-			}
-			comma = strchr (ctxt->line, ',');
-			if (comma != NULL) {
-				cell = sheet_cell_fetch (ctxt->sheet, col, row);
-				cell_set_text (cell, comma + 1);
-				col++;
+				break;
 			} else {
-				msg = g_strdup_printf (_("Syntax error at line %d. Ignoring."),
-				                       ctxt->line_no);
-				g_warning (msg);
-				g_free (msg);
+				gnm_float num = gnm_strto (comma+1, NULL);
+				GnmValue *v = NULL;
+
+				if (!dif_get_line (ctxt))
+					return FALSE;
+
+				if (0 == strcmp (ctxt->line, "V")) {		/* V       value */
+					v = value_new_float (num);
+				} else if (0 == strcmp (ctxt->line, "NA")) {	/* NA      not available res must be O */
+					v = value_new_error_NA (NULL);
+				} else if (0 == strcmp (ctxt->line, "TRUE")) {	/* TRUE    bool T	 res must be 1 */
+					v = value_new_bool (TRUE);
+				} else if (0 == strcmp (ctxt->line, "FALSE")) {	/* FALSE   bool F	 res must be O */
+					v = value_new_bool (TRUE);
+				} else if (0 == strcmp (ctxt->line, "ERROR")) {	/* ERROR   err		 res must be O */
+					gnm_io_warning (ctxt->io_context,
+							_("Unknown value type '%s' at line %d. Ignoring."),
+							ctxt->line, ctxt->line_no);
+				}
+
+				if (NULL != v) {
+					cell = sheet_cell_fetch (ctxt->sheet, col, row);
+					gnm_cell_set_value (cell, v);
+				}
+				col++;
 			}
 		} else if (val_type == 1) {
-			if (!dif_get_line (ctxt)) {
+			if (!dif_get_line (ctxt))
 				return FALSE;
-			}
 			if (col > SHEET_MAX_COLS) {
 				too_many_columns = TRUE;
 				continue;
 			}
-			cell_set_text (sheet_cell_fetch (ctxt->sheet, col, row),
-				ctxt->line);
+			cell = sheet_cell_fetch (ctxt->sheet, col, row);
+			if (ctxt->line_len >= 2 &&
+			    ctxt->line[0] == '"' && ctxt->line[ctxt->line_len - 1] == '"') {
+				ctxt->line[ctxt->line_len - 1] = '\0'; 	 
+				gnm_cell_set_text (cell, ctxt->line + 1); 	 
+			} else
+				gnm_cell_set_text (cell, ctxt->line);
 			col++;
 		} else if (val_type == -1) {
-			if (!dif_get_line (ctxt)) {
+			if (!dif_get_line (ctxt))
 				return FALSE;
-			}
 			if (strcmp (ctxt->line, "BOT") == 0) {
 				col = 0;
 				row++;
@@ -239,6 +262,8 @@ dif_parse_data (DifInputContext *ctxt)
 static void
 dif_parse_sheet (DifInputContext *ctxt)
 {
+	GnmLocale *locale = gnm_push_C_locale ();
+
 	if (!dif_parse_header (ctxt)) {
 		gnumeric_io_error_info_set (ctxt->io_context, error_info_new_printf (
 		_("Unexpected end of file at line %d while reading header."),
@@ -248,6 +273,8 @@ dif_parse_sheet (DifInputContext *ctxt)
 		_("Unexpected end of file at line %d while reading data."),
 		ctxt->line_no));
 	}
+
+	gnm_pop_C_locale (locale);
 }
 
 void
@@ -274,8 +301,9 @@ dif_file_open (GOFileOpener const *fo, IOContext *io_context,
  */
 void
 dif_file_save (GOFileSaver const *fs, IOContext *io_context,
-               WorkbookView const *wbv, GsfOutput *output)
+               WorkbookView const *wbv, GsfOutput *out)
 {
+	GnmLocale *locale;
 	Sheet *sheet;
 	GnmRange r;
 	gint row, col;
@@ -290,34 +318,49 @@ dif_file_save (GOFileSaver const *fs, IOContext *io_context,
 	r = sheet_get_extent (sheet, FALSE);
 
 	/* Write out the standard headers */
-	res  = gsf_output_puts (output, "TABLE\n" "0,1\n" "\"GNUMERIC\"\n");
-	if (res) res = gsf_output_printf (output,
-					  "VECTORS\n" "0,%d\n" "\"\"\n",
-					  r.end.row);
-	if (res) res = gsf_output_printf (output,
-					  "TUPLES\n" "0,%d\n" "\"\"\n",
-					  r.end.col);
-	if (res) res= gsf_output_puts (output, "DATA\n0,0\n" "\"\"\n");
+	gsf_output_puts   (out, "TABLE\n"   "0,1\n" "\"GNUMERIC\"\n");
+	gsf_output_printf (out, "VECTORS\n" "0,%d\n" "\"\"\n", r.end.row+1);
+	gsf_output_printf (out, "TUPLES\n"  "0,%d\n" "\"\"\n", r.end.col+1);
+	gsf_output_puts   (out, "DATA\n"    "0,0\n"  "\"\"\n");
+
+	locale = gnm_push_C_locale ();
 
 	/* Process all cells */
 	for (row = r.start.row; res && row <= r.end.row; row++) {
-		gsf_output_puts (output, "-1,0\n" "BOT\n");
+		gsf_output_puts (out, "-1,0\n" "BOT\n");
 		for (col = r.start.col; col <= r.end.col; col++) {
 			GnmCell *cell = sheet_cell_get (sheet, col, row);
-			if (cell_is_empty (cell)) {
-				gsf_output_puts(output, "1,0\n" "\"\"\n");
-			} else {
-				gchar *str;
-
-				str = cell_get_rendered_text (cell);
-				res = gsf_output_printf (output,
-							 "1.0\n" "\"%s\"\n",
+			if (gnm_cell_is_empty (cell)) {
+				gsf_output_puts(out, "1,0\n" "\"\"\n");
+			} else if (VALUE_IS_BOOLEAN (cell->value)) {
+				if (value_get_as_checked_bool (cell->value))
+					gsf_output_puts(out, "0,1\n" "TRUE\n");
+				else
+					gsf_output_puts(out, "0,0\n" "FALSE\n");
+			} else if (VALUE_IS_ERROR (cell->value)) {
+				if (value_error_classify (cell->value) == GNM_ERROR_NA)
+					gsf_output_puts(out, "0,0\n" "NA\n");
+				else
+					gsf_output_puts(out, "0,0\n" "ERROR\n");
+			} else if (VALUE_IS_FLOAT (cell->value))
+				gsf_output_printf (out, "0,%" GNM_FORMAT_g "\n" "V\n",
+					value_get_as_float (cell->value));
+			else {
+				gchar *str = gnm_cell_get_rendered_text (cell);
+				res = gsf_output_printf (out,
+							 "1,0\n" "\"%s\"\n",
 							 str);
 				g_free (str);
 			}
 		}
 	}
-	gsf_output_puts (output, "-1,0\n" "EOD\n");
+
+	/* This BOT is not required as far as I can tel, but MS seems to puts
+	 * one here, and it may be useful to be compatible  */
+	gsf_output_puts (out, "-1,0\n" "BOT\n");
+	gsf_output_puts (out, "-1,0\n" "EOD\n");
+
+	gnm_pop_C_locale (locale);
 
 	if (!res)
 		gnumeric_io_error_string (io_context, _("Error while saving DIF file."));
