@@ -1,5 +1,5 @@
 /* vim: set sw=8:
- * $Id: boot.c,v 1.11 2005/03/04 17:58:23 jody Exp $
+ * $Id: boot.c,v 1.13 2006/03/19 17:12:10 jody Exp $
  */
 
 /*
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 #include <gnumeric-config.h>
@@ -53,5 +53,5 @@ void
 psiconv_file_open (GOFileOpener const *fo, IOContext *io_context,
                   WorkbookView *wb_view, GsfInput *input)
 {
-	psiconv_read (io_context, wb_view_workbook(wb_view), input);
+	psiconv_read (io_context, wb_view_get_workbook(wb_view), input);
 }
