@@ -24,6 +24,7 @@
 #include "clipboard.h"
 
 #include "sheet.h"
+#include "cell.h"
 #include "sheet-style.h"
 #include "sheet-merge.h"
 #include "dependent.h"
@@ -460,7 +461,7 @@ clipboard_paste_region (GnmCellRegion const *cr,
 				continue;
 			}
 
-			if (has_contents) {
+			if (has_contents && NULL != cr->cell_content) {
 				dat.pt = pt;
 				g_hash_table_foreach (cr->cell_content,
 					(GHFunc)cb_paste_cell, &dat);
@@ -476,7 +477,7 @@ clipboard_paste_region (GnmCellRegion const *cr,
 			sheet_region_queue_recalc (pt->sheet, r);
 			sheet_flag_status_update_range (pt->sheet, r);
 		} else
-			sheet_flag_format_update_range (pt->sheet, r);
+			sheet_flag_style_update_range (pt->sheet, r);
 
 		sheet_range_calc_spans (pt->sheet, r,
 					(pt->paste_flags & PASTE_FORMATS) ? GNM_SPANCALC_RE_RENDER : GNM_SPANCALC_RENDER);
@@ -707,10 +708,13 @@ cellregion_unref (GnmCellRegion *cr)
 static GnmCellCopy *
 cellregion_get_content (GnmCellRegion const *cr, int col, int row)
 {
-	GnmCellPos pos;
-	pos.col = col;
-	pos.row = row;
-	return g_hash_table_lookup (cr->cell_content, &pos);
+	if (cr->cell_content) {
+		GnmCellPos pos;
+		pos.col = col;
+		pos.row = row;
+		return g_hash_table_lookup (cr->cell_content, &pos);
+	} else
+		return NULL;
 }
 
 static void
@@ -769,13 +773,15 @@ cellregion_to_string (GnmCellRegion const *cr,
 	int cols, rows, col, row, next_col_check, next_row_check;
 	ColRowStateList	const *col_state, *row_state;
 	ColRowRLEState const *rle;
+	int ncells;
 
 	g_return_val_if_fail (cr != NULL, NULL);
 	g_return_val_if_fail (cr->rows >= 0, NULL);
 	g_return_val_if_fail (cr->cols >= 0, NULL);
 
 	/* pre-allocate rough approximation of buffer */
-	all = g_string_sized_new (20 * g_hash_table_size (cr->cell_content));
+	ncells = cr->cell_content ? g_hash_table_size (cr->cell_content) : 0;
+	all = g_string_sized_new (20 * ncells + 1);
 	line = g_string_new (NULL);
 
 	cols = cr->cols;
@@ -830,9 +836,14 @@ cellregion_to_string (GnmCellRegion const *cr,
 int
 cellregion_cmd_size (GnmCellRegion const *cr)
 {
-	return (g_hash_table_size (cr->cell_content) +
-		g_slist_length (cr->styles) +
-		1);
+	int res = 1;
+	
+	g_return_val_if_fail (cr != NULL, 1);
+
+	res += g_slist_length (cr->styles);
+	if (NULL != cr->cell_content)
+		res += g_hash_table_size (cr->cell_content);
+	return res;
 }
 
 static void
