@@ -24,7 +24,7 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "analysis-tools.h"
@@ -80,7 +80,7 @@
 #define ANOVA_SINGLE_KEY      "analysistools-anova-single-factor-dialog"
 
 
-static const char * const grouped_by_group[] = {
+static char const * const grouped_by_group[] = {
 	"grouped_by_row",
 	"grouped_by_col",
 	"grouped_by_area",
@@ -192,7 +192,7 @@ typedef struct {
  * Show an error dialog and select corresponding entry
  */
 void
-error_in_entry (GenericToolState *state, GtkWidget *entry, const char *err_str)
+error_in_entry (GenericToolState *state, GtkWidget *entry, char const *err_str)
 {
         go_gtk_notice_nonmodal_dialog ((GtkWindow *) state->dialog,
 				  &(state->warning_dialog),
@@ -204,39 +204,17 @@ error_in_entry (GenericToolState *state, GtkWidget *entry, const char *err_str)
 		focus_on_entry (GTK_ENTRY (entry));
 }
 
-/**
- * tool_destroy:
- * @window:
- * @state:
- *
- * Destroy the dialog and associated data structures.
- *
- **/
-static gboolean
-tool_destroy (GtkObject *w, GenericToolState  *state)
+static void
+cb_tool_destroy (GenericToolState  *state)
 {
-	gboolean res = FALSE;
-
-	g_return_val_if_fail (w != NULL, FALSE);
-	g_return_val_if_fail (state != NULL, FALSE);
-
 	wbcg_edit_detach_guru (state->wbcg);
 
-	if (state->gui != NULL) {
+	if (state->gui != NULL)
 		g_object_unref (G_OBJECT (state->gui));
-		state->gui = NULL;
-	}
-
 	wbcg_edit_finish (state->wbcg, WBC_EDIT_REJECT, NULL);
-
-	state->dialog = NULL;
-
 	if (state->state_destroy)
-		res = state->state_destroy (w, state);
-
+		state->state_destroy (state);
 	g_free (state);
-
-	return (FALSE || res);
 }
 
 /**
@@ -413,8 +391,8 @@ dialog_tool_init (GenericToolState *state,
 
 	state->warning = glade_xml_get_widget (state->gui, "warnings");
 	wbcg_edit_attach_guru (state->wbcg, state->dialog);
-	g_signal_connect (G_OBJECT (state->dialog), "destroy",
-			  G_CALLBACK (tool_destroy), state);
+	g_object_set_data_full (G_OBJECT (state->dialog),
+		"state", state, (GDestroyNotify) cb_tool_destroy);
 
 	dialog_tool_init_outputs (state, sensitivity_cb);
 
