@@ -20,7 +20,7 @@
  */
 
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
@@ -158,7 +158,7 @@ cb_autofilter_ok (G_GNUC_UNUSED GtkWidget *button,
 	}
 	if (cond != NULL) {
 		gnm_filter_set_condition (state->filter, state->field,
-				 cond, TRUE);
+			cond, TRUE);
 		sheet_update (state->filter->sheet);
 	}
 
