@@ -115,7 +115,7 @@ stf_export_dialog_format_page_init (TextExportState *state)
 	gnumeric_editable_enters (state->window,
 			gtk_bin_get_child (GTK_BIN (state->format.quotechar)));
 
-	if (stf_export_can_transliterate ()) {
+	if (gnm_stf_export_can_transliterate ()) {
 		gtk_combo_box_set_active (state->format.transliterate,
 			GNM_STF_TRANSLITERATE_MODE_TRANS);
 	} else {
@@ -152,7 +152,7 @@ cb_collect_exported_sheets (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter
 		STF_EXPORT_COL_SHEET,	 &sheet,
 		-1);
 	if (exported)
-		stf_export_options_sheet_list_add (state->result, sheet);
+		gnm_stf_export_options_sheet_list_add (state->result, sheet);
 	g_object_unref (sheet);
 	return FALSE;
 }
@@ -239,7 +239,7 @@ stf_export_dialog_finish (TextExportState *state)
 		 NULL);
 
 	/* Which sheets */
-	stf_export_options_sheet_list_clear (state->result);
+	gnm_stf_export_options_sheet_list_clear (state->result);
 	gtk_tree_model_foreach (GTK_TREE_MODEL (state->sheets.model),
 		(GtkTreeModelForeachFunc) cb_collect_exported_sheets, state);
 
@@ -310,10 +310,10 @@ cb_selection_changed (GtkTreeSelection *new_selection,
 		: new_selection;
 
 	if (selection != NULL 
-	    && gtk_tree_selection_count_selected_rows (selection) > 0) {
-		gtk_tree_model_get_iter_first 
-			(GTK_TREE_MODEL (state->sheets.model),
-			 &iter);
+	    && gtk_tree_selection_count_selected_rows (selection) > 0
+	    && gtk_tree_model_get_iter_first 
+		       (GTK_TREE_MODEL (state->sheets.model),
+			&iter)) {
 		first_selected = gtk_tree_selection_iter_is_selected 
 			(selection, &iter);
 		it = iter;
@@ -403,16 +403,23 @@ cb_sheet_export_toggled (GtkCellRendererToggle *cell,
 	GtkTreeIter  iter;
 	gboolean value;
 
-	gtk_tree_model_get_iter (GTK_TREE_MODEL (state->sheets.model), &iter, path);
+	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (state->sheets.model), 
+				     &iter, path)) {
+		gtk_tree_model_get 
+			(GTK_TREE_MODEL (state->sheets.model), &iter,
+			 STF_EXPORT_COL_EXPORTED,	&value,
+			 -1);
+		gtk_list_store_set 
+			(state->sheets.model, &iter,
+			 STF_EXPORT_COL_EXPORTED,	!value,
+			 -1);
+		set_sheet_selection_count 
+			(state,
+			 state->sheets.num_selected + (value ? -1 : 1));
+	} else {
+		g_warning ("Did not get a valid iterator");
+	}
 	gtk_tree_path_free (path);
-	gtk_tree_model_get (GTK_TREE_MODEL (state->sheets.model), &iter,
-		STF_EXPORT_COL_EXPORTED,	&value,
-		-1);
-	gtk_list_store_set (state->sheets.model, &iter,
-		STF_EXPORT_COL_EXPORTED,	!value,
-		-1);
-	set_sheet_selection_count (state,
-		state->sheets.num_selected + (value ? -1 : 1));
 }
 
 static void
