@@ -172,6 +172,27 @@ gnm_named_expr_collection_lookup (GnmNamedExprCollection const *scope,
 		return NULL;
 }
 
+static void
+cb_list_names (G_GNUC_UNUSED gpointer key,
+	       gpointer value,
+	       gpointer user_data)
+{
+	GSList **pres = user_data;
+	GO_SLIST_PREPEND (*pres, value);
+}
+
+GSList *
+gnm_named_expr_collection_list (GnmNamedExprCollection const *scope)
+{
+	GSList *res = NULL;
+	if (scope && scope->names) {
+		g_hash_table_foreach (scope->names,
+				      cb_list_names,
+				      &res);
+	}
+	return res;
+}
+
 static void
 gnm_named_expr_collection_insert (GnmNamedExprCollection const *scope,
 				  GnmNamedExpr *nexpr)
@@ -857,8 +878,8 @@ sheet_names_check (Sheet const *sheet, GnmRange const *r)
  **/
 void
 expr_name_perm_add (Sheet *sheet, char const *name,
-				GnmExprTop const *value,
-				gboolean is_editable)
+		    GnmExprTop const *value,
+		    gboolean is_editable)
 {
 	GnmNamedExpr *res;
 	GnmParsePos pp;
@@ -873,3 +894,26 @@ expr_name_perm_add (Sheet *sheet, char const *name,
 
 }
 
+/* ------------------------------------------------------------------------- */
+
+static void
+expr_name_set_expr_ref (GnmNamedExpr *nexpr, GnmExprTop const *texpr)
+{
+	gnm_expr_top_ref (texpr);
+	expr_name_set_expr (nexpr, texpr);
+}
+
+
+GOUndo *
+expr_name_set_expr_undo_new (GnmNamedExpr *ne)
+{
+	expr_name_ref (ne);
+	gnm_expr_top_ref (ne->texpr);
+
+	return go_undo_binary_new (ne, (gpointer)ne->texpr,
+				   (GFunc)expr_name_set_expr_ref,
+				   (GFreeFunc)expr_name_unref,
+				   (GFreeFunc)gnm_expr_top_unref);
+}
+
+/* ------------------------------------------------------------------------- */
