@@ -95,7 +95,7 @@ gnumeric_pane_header_init (GnmPane *pane, SheetControlGUI *scg,
 	pane->size_guide.guide  = NULL;
 
 	if (NULL != scg &&
-	    NULL != (sheet = sc_sheet (SHEET_CONTROL (scg))) &&
+	    NULL != (sheet = scg_sheet (scg)) &&
 	    fabs (1. - sheet->last_zoom_factor_used) > 1e-6)
 		foo_canvas_set_pixels_per_unit (canvas, sheet->last_zoom_factor_used);
 
@@ -139,7 +139,7 @@ gnm_pane_display_obj_size_tip (GnmPane *pane, SheetObject const *so)
 
 	sheet_object_anchor_cpy	(&anchor, sheet_object_get_anchor (so));
 	scg_object_coords_to_anchor (scg, coords, &anchor);
-	sheet_object_anchor_to_pts (&anchor, sc_sheet (SHEET_CONTROL (scg)), pts);
+	sheet_object_anchor_to_pts (&anchor, scg_sheet (scg), pts);
 	msg = g_strdup_printf (_("%.1f x %.1f pts\n%d x %d pixels"),
 		MAX (fabs (pts[2] - pts[0]), 0),
 		MAX (fabs (pts[3] - pts[1]), 0),
@@ -211,7 +211,7 @@ cb_pane_drag_motion (GtkWidget *widget, GdkDragContext *context,
 		double wx, wy;
 
 		g_object_set_data (&context->parent_instance,
-			"wbcg", scg_get_wbcg (scg));
+			"wbcg", scg_wbcg (scg));
 		gnm_canvas_window_to_coord (gcanvas, x, y, &wx, &wy);
 
 		gdk_window_get_pointer (gtk_widget_get_parent_window (source_widget),
@@ -251,13 +251,11 @@ cb_pane_drag_leave (GtkWidget *widget, GdkDragContext *context,
 	GnmPane *source_pane;
 	WorkbookControlGUI *wbcg;
   
-	if (!source_widget) return;
-
-	g_return_if_fail (IS_GNM_CANVAS (source_widget));
+	if (!source_widget || !IS_GNM_CANVAS (source_widget)) return;
 
 	source_pane = GNM_CANVAS (source_widget)->pane;
 
-	wbcg = scg_get_wbcg (source_pane->gcanvas->simple.scg);
+	wbcg = scg_wbcg (source_pane->gcanvas->simple.scg);
 	if (wbcg == g_object_get_data (&context->parent_instance, "wbcg"))
 		return;
 
@@ -293,7 +291,7 @@ static void
 cb_pane_init_objs (GnmPane *pane)
 {
 	/* create views for the sheet objects now that we exist */
-	Sheet *sheet = sc_sheet (SHEET_CONTROL (pane->gcanvas->simple.scg));
+	Sheet *sheet = scg_sheet (pane->gcanvas->simple.scg);
 	GSList *ptr;
 
 	if (sheet != NULL)
@@ -321,7 +319,7 @@ gnm_pane_init (GnmPane *pane, SheetControlGUI *scg,
 		G_CALLBACK (cb_pane_init_objs), pane);
 
 	if (NULL != scg &&
-	    NULL != (sheet = sc_sheet (SHEET_CONTROL (scg))) &&
+	    NULL != (sheet = scg_sheet (scg)) &&
 	    fabs (1. - sheet->last_zoom_factor_used) > 1e-6)
 		foo_canvas_set_pixels_per_unit (FOO_CANVAS (pane->gcanvas),
 						sheet->last_zoom_factor_used);
@@ -591,19 +589,19 @@ void
 gnm_pane_rangesel_start (GnmPane *pane, GnmRange const *r)
 {
 	FooCanvasItem *item;
-	SheetControl *sc = (SheetControl *) pane->gcanvas->simple.scg;
+	SheetControlGUI *scg = pane->gcanvas->simple.scg;
 
 	g_return_if_fail (pane->cursor.rangesel == NULL);
 
 	/* Hide the primary cursor while the range selection cursor is visible
 	 * and we are selecting on a different sheet than the expr being edited
 	 */
-	if (sc_sheet (sc) != wb_control_cur_sheet (sc_wbc (sc)))
+	if (scg_sheet (scg) != wb_control_cur_sheet (scg_wbc (scg)))
 		item_cursor_set_visibility (pane->cursor.std, FALSE);
 
 	item = foo_canvas_item_new (pane->gcanvas->grid_items,
 		item_cursor_get_type (),
-		"SheetControlGUI", pane->gcanvas->simple.scg,
+		"SheetControlGUI", scg,
 		"style",	ITEM_CURSOR_ANTED,
 		NULL);
 	pane->cursor.rangesel = ITEM_CURSOR (item);
@@ -681,7 +679,7 @@ void
 gnm_pane_edit_start (GnmPane *pane)
 {
 	GnmCanvas const *gcanvas = pane->gcanvas;
-	SheetView const *sv = sc_view (SHEET_CONTROL (gcanvas->simple.scg));
+	SheetView const *sv = scg_view (gcanvas->simple.scg);
 	GnmCellPos const *edit_pos;
 
 	g_return_if_fail (pane->editor == NULL);
@@ -1059,7 +1057,7 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event, GnmPane *pane)
 	SheetObject *so;
 	int idx;
 
-	if (wbcg_edit_get_guru (scg_get_wbcg (scg)) != NULL)
+	if (wbcg_edit_get_guru (scg_wbcg (scg)) != NULL)
 		return FALSE;
 
 	so  = g_object_get_data (G_OBJECT (ctrl_pt), "so");
@@ -1262,7 +1260,8 @@ set_acetate_coords (GnmPane *pane, SheetObject *so, FooCanvasItem **ctrl_pts,
 			sov = sheet_object_new_view (so, (SheetObjectViewContainer *)pane);
 
 		coords [0] = l; coords [2] = r; coords [1] = t; coords [3] = b;
-		sheet_object_view_set_bounds (sov, coords, TRUE);
+		if (NULL != sov)
+			sheet_object_view_set_bounds (sov, coords, TRUE);
 		normalize_high_low (r, l);
 		normalize_high_low (b, t);
 	}
@@ -1371,7 +1370,7 @@ cb_sheet_object_canvas_event (FooCanvasItem *view, GdkEvent *event,
 	case GDK_ENTER_NOTIFY:
 		gnm_widget_set_cursor_type (GTK_WIDGET (view->canvas),
 			(so->flags & SHEET_OBJECT_CAN_PRESS) ? GDK_HAND2 : GDK_ARROW);
-		break;
+		return FALSE;
 
 	case GDK_BUTTON_PRESS:
 		if (event->button.button > 3)
@@ -1379,6 +1378,12 @@ cb_sheet_object_canvas_event (FooCanvasItem *view, GdkEvent *event,
 
 		/* cb_sheet_object_widget_canvas_event calls even if selected */
 		if (NULL == g_hash_table_lookup (pane->drag.ctrl_pts, so)) {
+			SheetObjectClass *soc =
+				G_TYPE_INSTANCE_GET_CLASS (so, SHEET_OBJECT_TYPE, SheetObjectClass);
+
+			if (soc->interactive && event->button.button != 3)
+				return FALSE;
+
 			if (!(event->button.state & GDK_SHIFT_MASK))
 				scg_object_unselect (pane->gcanvas->simple.scg, NULL);
 			scg_object_select (pane->gcanvas->simple.scg, so);
@@ -1417,13 +1422,6 @@ cb_sheet_object_widget_canvas_event (GtkWidget *widget, GdkEvent *event,
 	    (event->type == GDK_BUTTON_PRESS && event->button.button == 3))
 		return cb_sheet_object_canvas_event (view, event,
 			sheet_object_view_get_so (SHEET_OBJECT_VIEW (view)));
-	if (event->type == GDK_2BUTTON_PRESS && event->button.button == 1) {
-		sheet_object_get_editor (
-			sheet_object_view_get_so (SHEET_OBJECT_VIEW (view)),
-			SHEET_CONTROL (GNM_SIMPLE_CANVAS (view->canvas)->scg));
-		return TRUE;
-	}
-
 	return FALSE;
 }
 
