@@ -8,7 +8,7 @@
  *   Miguel de Icaza (miguel@gnu.org)
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include "gnumeric.h"
 #include "libgnumeric.h"
 
@@ -29,8 +29,8 @@
 #include "str.h"
 #include "dependent.h"
 #include "sheet-autofill.h"
+#include "sheet-private.h"
 #include "xml-io.h"
-#include "cell.h"
 #include "clipboard.h"
 #include "value.h"
 #include "expr.h"
@@ -122,15 +122,15 @@ gnm_common_init (gboolean fast)
 	value_init ();
 	parse_util_init ();
 	expr_init ();
-	cell_init ();
+	gnm_sheet_cell_init ();
 	clipboard_init ();
 	dependent_types_init ();
-	rendered_value_init ();
+	gnm_rendered_value_init ();
 	gnumeric_color_init ();
 	style_init ();
 	functions_init ();
 	print_init ();
-	autofill_init ();
+	gnm_autofill_init ();
 	sheet_objects_init ();
 
 	/* make sure that all hlink types are registered */
@@ -177,15 +177,15 @@ gnm_shutdown (void)
 		go_conf_sync (NULL);
 	}
 
-	autofill_shutdown ();
+	gnm_autofill_shutdown ();
 	print_shutdown ();
 	functions_shutdown ();
 	style_shutdown ();
 	gnumeric_color_shutdown ();
-	rendered_value_shutdown ();
+	gnm_rendered_value_shutdown ();
 	dependent_types_shutdown ();
 	clipboard_shutdown ();
-	cell_shutdown ();
+	gnm_sheet_cell_shutdown ();
 	expr_shutdown ();
 	parse_util_shutdown ();
 	value_shutdown ();
