@@ -70,7 +70,7 @@ comment_view_set_bounds (SheetObjectView *sov, double const *coords, gboolean vi
 		double scale;
 		int x, y, far_col;
 		FooCanvasPoints *points = foo_canvas_points_new (3);
-		GnmRange const *r = sheet_merge_is_corner (so->sheet,
+		GnmRange const *r = gnm_sheet_merge_is_corner (so->sheet,
 			&so->anchor.cell_bound.start);
 
 		if (r != NULL) {
@@ -275,15 +275,6 @@ cell_comment_read_xml_dom (SheetObject *so, char const *typename,
 	return FALSE;
 }
 
-static gboolean
-cell_comment_write_xml_dom (SheetObject const *so, XmlParseContext const *ctxt,
-			    xmlNodePtr tree)
-{
-	GnmComment const *cc = CELL_COMMENT (so);
-	xml_node_set_cstr (tree, "Author", cc->author);
-	xml_node_set_cstr (tree, "Text", cc->text);
-	return FALSE;
-}
 static void
 cell_comment_write_xml_sax (SheetObject const *so, GsfXMLOut *output)
 {
@@ -294,6 +285,7 @@ cell_comment_write_xml_sax (SheetObject const *so, GsfXMLOut *output)
 		gsf_xml_out_add_cstr (output, "Text", cc->text);
 }
 
+#ifdef WITH_GNOME_PRINT
 static void
 cell_comment_print (SheetObject const *so, GnomePrintContext *ctx,
 		    double base_x, double base_y)
@@ -303,14 +295,15 @@ cell_comment_print (SheetObject const *so, GnomePrintContext *ctx,
 	 * about an unprintable sheet object.
 	 */
 }
+#endif
 
 static void
 cell_comment_copy (SheetObject *dst, SheetObject const *src)
 {
 	GnmComment const *comment	= CELL_COMMENT (src);
 	GnmComment	 *new_comment	= CELL_COMMENT (dst);
-	new_comment->author = comment->author ? g_strdup (comment->author) : NULL;
-	new_comment->text   = comment->text   ? g_strdup (comment->text) : NULL;
+	new_comment->author = g_strdup (comment->author);
+	new_comment->text   = g_strdup (comment->text);
 }
 
 static void
@@ -335,9 +328,13 @@ cell_comment_class_init (GObjectClass *gobject_class)
 	/* SheetObject class method overrides */
 	sheet_object_class->new_view		= &cell_comment_new_view;
 	sheet_object_class->read_xml_dom	= &cell_comment_read_xml_dom;
-	sheet_object_class->write_xml_dom	= &cell_comment_write_xml_dom;
 	sheet_object_class->write_xml_sax	= &cell_comment_write_xml_sax;
+	sheet_object_class->print		= NULL;
+
+#ifdef WITH_GNOME_PRINT
 	sheet_object_class->print		= &cell_comment_print;
+#endif
+
 	sheet_object_class->copy		= &cell_comment_copy;
 	sheet_object_class->xml_export_name = "CellComment";
 }
@@ -364,9 +361,8 @@ cell_comment_author_set (GnmComment *cc, char const *author)
 	char *tmp;
 	g_return_if_fail (IS_CELL_COMMENT (cc));
 
-	tmp = author ? g_strdup (author) : NULL;
-	if (cc->author)
-		g_free (cc->author);
+	tmp = g_strdup (author);
+	g_free (cc->author);
 	cc->author = tmp;
 }
 
@@ -383,9 +379,8 @@ cell_comment_text_set (GnmComment *cc, char const *text)
 	char *tmp;
 	g_return_if_fail (IS_CELL_COMMENT (cc));
 
-	tmp = text ? g_strdup (text) : NULL;
-	if (cc->text)
-		g_free (cc->text);
+	tmp = g_strdup (text);
+	g_free (cc->text);
 	cc->text = tmp;
 }
 
@@ -394,20 +389,15 @@ void
 cell_comment_set_cell (GnmComment *cc, GnmCellPos const *pos)
 {
 	/* top right */
-	static SheetObjectAnchorType const anchor_types [4] = {
-		SO_ANCHOR_PERCENTAGE_FROM_COLROW_END,
-		SO_ANCHOR_PERCENTAGE_FROM_COLROW_START,
-		SO_ANCHOR_PERCENTAGE_FROM_COLROW_END,
-		SO_ANCHOR_PERCENTAGE_FROM_COLROW_START
-	};
+	static float const a_offsets [4] = { 1., 0., 1., 0. };
 	SheetObjectAnchor anchor;
 	GnmRange	  r;
 
 	g_return_if_fail (IS_CELL_COMMENT (cc));
 
 	r.start = r.end = *pos;
-	sheet_object_anchor_init (&anchor, &r, NULL,
-		anchor_types, SO_DIR_DOWN_RIGHT);
+	sheet_object_anchor_init (&anchor, &r, a_offsets,
+		NULL, GOD_ANCHOR_DIR_DOWN_RIGHT);
 	sheet_object_set_anchor (SHEET_OBJECT (cc), &anchor);
 }
 
@@ -421,8 +411,8 @@ cell_set_comment (Sheet *sheet, GnmCellPos const *pos,
 	g_return_val_if_fail (pos != NULL, NULL);
 
 	cc = g_object_new (CELL_COMMENT_TYPE, NULL);
-	cc->author = author ? g_strdup (author) : NULL;
-	cc->text = text ? g_strdup (text) : NULL;
+	cc->author = g_strdup (author);
+	cc->text = g_strdup (text);
 
 	cell_comment_set_cell (cc, pos);
 
