@@ -3,7 +3,7 @@
 /*
  * sheet-object-widget.c: SheetObject wrappers for simple gtk widgets.
  *
- * Copyright (C) 2000-2005 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2000-2006 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,7 +21,7 @@
  * USA
  */
 #include <gnumeric-config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include "gnumeric.h"
 #include "sheet-object-widget.h"
 
@@ -54,17 +54,7 @@
 #include <libxml/globals.h>
 #include <goffice/cut-n-paste/foocanvas/foo-canvas-widget.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkradiobutton.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkhscrollbar.h>
-#include <gtk/gtkvscrollbar.h>
-#include <gtk/gtkhscale.h>
-#include <gtk/gtkvscale.h>
+#include <gtk/gtk.h>
 #include <math.h>
 
 
@@ -116,7 +106,7 @@ static GSF_CLASS_FULL (SOWidgetFooView, so_widget_foo_view,
 #define SOW_CLASS(so)	 	     (SHEET_OBJECT_WIDGET_CLASS (G_OBJECT_GET_CLASS(so)))
 
 #define SOW_MAKE_TYPE(n1, n2, fn_config, fn_set_sheet, fn_clear_sheet,			\
-		      fn_copy, fn_write_dom, fn_read_dom, fn_write_sax,			\
+		      fn_copy, fn_read_dom, fn_write_sax,				\
 	              fn_get_property, fn_set_property, class_init_code)		\
 static void										\
 sheet_widget_ ## n1 ## _class_init (GObjectClass *object_class)				\
@@ -127,10 +117,10 @@ sheet_widget_ ## n1 ## _class_init (GObjectClass *object_class)				\
 	object_class->set_property	= fn_set_property;				\
 	object_class->get_property	= fn_get_property;				\
 	so_class->user_config		= fn_config;					\
+        so_class->interactive           = TRUE;						\
 	so_class->assign_to_sheet	= fn_set_sheet;					\
 	so_class->remove_from_sheet	= fn_clear_sheet;				\
 	so_class->copy			= fn_copy;					\
-	so_class->write_xml_dom		= fn_write_dom;					\
 	so_class->read_xml_dom		= fn_read_dom;					\
 	so_class->write_xml_sax		= fn_write_sax;					\
 	sow_class->create_widget     	= &sheet_widget_ ## n1 ## _create_widget;	\
@@ -156,9 +146,9 @@ static GType sheet_object_widget_get_type	(void);
 static void
 sax_write_dep (GsfXMLOut *output, GnmDependent const *dep, char const *id)
 {
-	if (dep->expression != NULL) {
+	if (dep->texpr != NULL) {
 		GnmParsePos pos;
-		char *val = gnm_expr_as_string (dep->expression,
+		char *val = gnm_expr_top_as_string (dep->texpr,
 			parse_pos_init_sheet (&pos, dep->sheet),
 			gnm_expr_conventions_default);
 		gsf_xml_out_add_cstr (output, id, val);
@@ -166,19 +156,6 @@ sax_write_dep (GsfXMLOut *output, GnmDependent const *dep, char const *id)
 	}
 }
 
-static void
-dom_write_dep (xmlNodePtr tree, GnmDependent const *dep, char const *id)
-{
-	if (dep->expression != NULL) {
-		GnmParsePos pos;
-		char *val = gnm_expr_as_string (dep->expression,
-			parse_pos_init_sheet (&pos, dep->sheet),
-			gnm_expr_conventions_default);
-		xml_node_set_cstr (tree, id, val);
-		g_free (val);
-	}
-}
-
 static void
 read_dep (GnmDependent *dep, char const *name,
 	  xmlNodePtr tree, XmlParseContext const *context)
@@ -186,12 +163,11 @@ read_dep (GnmDependent *dep, char const *name,
 	char *txt = (gchar *)xmlGetProp (tree, (xmlChar *)name);
 
 	dep->sheet = NULL;
-	dep->expression = NULL;
+	dep->texpr = NULL;
 	if (txt != NULL && *txt != '\0') {
 		GnmParsePos pos;
-		GnmExpr const *expr = gnm_expr_parse_str_simple (txt,
+		dep->texpr = gnm_expr_parse_str_simple (txt,
 			parse_pos_init_sheet (&pos, context->sheet));
-		dep->expression = expr;
 		xmlFree (txt);
 	}
 }
@@ -267,12 +243,10 @@ sheet_widget_frame_finalize (GObject *obj)
 {
 	SheetWidgetFrame *swf = SHEET_WIDGET_FRAME (obj);
 
-	if (swf->label != NULL) {
-		g_free (swf->label);
-		swf->label = NULL;
-	}
+	g_free (swf->label);
+	swf->label = NULL;
 
-	(*sheet_object_widget_class->finalize) (obj);
+	sheet_object_widget_class->finalize (obj);
 }
 
 static GtkWidget *
@@ -296,18 +270,6 @@ sheet_widget_frame_write_xml_sax (SheetObject const *so, GsfXMLOut *output)
 	gsf_xml_out_add_cstr (output, "Label", swf->label);
 }
 
-static gboolean
-sheet_widget_frame_write_xml_dom (SheetObject const 	*so,
-				  XmlParseContext const *context,
-				  xmlNodePtr tree)
-{
-	SheetWidgetFrame *swf = SHEET_WIDGET_FRAME (so);
-
-	xml_node_set_cstr (tree, "Label", swf->label);
-
-	return FALSE;
-}
-
 static gboolean
 sheet_widget_frame_read_xml_dom (SheetObject *so, char const *typename,
 				 XmlParseContext const *context,
@@ -371,8 +333,7 @@ cb_frame_config_cancel_clicked (GtkWidget *button, FrameConfigState *state)
   	GList *ptr;
   	SheetWidgetFrame *swc = state->swc;
 
-  	if (swc->label)
-  		g_free(swc->label);
+	g_free (swc->label);
 
   	swc->label = g_strdup(state->old_label);
   	for (ptr = swc->sow.realized_list; ptr != NULL ; ptr = ptr->next)
@@ -392,10 +353,9 @@ cb_frame_label_changed(GtkWidget *entry, FrameConfigState *state)
 
   	text = gtk_entry_get_text(GTK_ENTRY(entry));
   	swc = state->swc;
-  	if (swc->label)
-  		g_free(swc->label);
+	g_free (swc->label);
 
-	swc->label = g_strdup(text);
+	swc->label = g_strdup (text);
   	for (ptr = swc->sow.realized_list; ptr != NULL; ptr = ptr->next) {
 		gtk_frame_set_label
 			(GTK_FRAME (FOO_CANVAS_WIDGET (ptr->data)->widget),
@@ -407,7 +367,7 @@ static void
 sheet_widget_frame_user_config (SheetObject *so, SheetControl *sc)
 {
   	SheetWidgetFrame *swc = SHEET_WIDGET_FRAME (so);
-  	WorkbookControlGUI   *wbcg = scg_get_wbcg (SHEET_CONTROL_GUI (sc));
+  	WorkbookControlGUI   *wbcg = scg_wbcg (SHEET_CONTROL_GUI (sc));
   	FrameConfigState *state;
   	GtkWidget *table;
 
@@ -468,7 +428,6 @@ SOW_MAKE_TYPE (frame, Frame,
 	       NULL,
 	       NULL,
 	       &sheet_widget_frame_copy,
-	       &sheet_widget_frame_write_xml_dom,
 	       &sheet_widget_frame_read_xml_dom,
 	       &sheet_widget_frame_write_xml_sax,
 	       NULL,
@@ -544,19 +503,6 @@ sheet_widget_button_write_xml_sax (SheetObject const *so, GsfXMLOut *output)
 	gsf_xml_out_add_cstr (output, "Label", swb->label);
 }
 
-static gboolean
-sheet_widget_button_write_xml_dom (SheetObject const	 *so,
-				   XmlParseContext const *context,
-				   xmlNodePtr tree)
-{
-	// FIXME: markup
-	SheetWidgetButton *swb = SHEET_WIDGET_BUTTON (so);
-
-	xml_node_set_cstr (tree, "Label", swb->label);
-
-	return FALSE;
-}
-
 static gboolean
 sheet_widget_button_read_xml_dom (SheetObject *so, char const *typename,
 				  XmlParseContext const *context,
@@ -666,7 +612,6 @@ SOW_MAKE_TYPE (button, Button,
 	       NULL,
 	       NULL,
 	       sheet_widget_button_copy,
-	       sheet_widget_button_write_xml_dom,
 	       sheet_widget_button_read_xml_dom,
 	       sheet_widget_button_write_xml_sax,
 	       sheet_widget_button_get_property,
@@ -716,8 +661,8 @@ adjustment_eval (GnmDependent *dep)
 	GnmValue *v;
 	GnmEvalPos pos;
 
-	v = gnm_expr_eval (dep->expression, eval_pos_init_dep (&pos, dep),
-			   GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
+	v = gnm_expr_top_eval (dep->texpr, eval_pos_init_dep (&pos, dep),
+			       GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
 	sheet_widget_adjustment_set_value (DEP_TO_ADJUSTMENT(dep),
 		value_get_as_float (v));
 	value_release (v);
@@ -738,10 +683,10 @@ sheet_widget_adjustment_get_ref (SheetWidgetAdjustment const *swa,
 	GnmValue *target;
 	g_return_val_if_fail (swa != NULL, NULL);
 
-	if (swa->dep.expression == NULL)
+	if (swa->dep.texpr == NULL)
 		return NULL;
 
-	target = gnm_expr_get_range (swa->dep.expression);
+	target = gnm_expr_top_get_range (swa->dep.texpr);
 	if (target == NULL)
 		return NULL;
 
@@ -755,7 +700,7 @@ sheet_widget_adjustment_get_ref (SheetWidgetAdjustment const *swa,
 
 static void
 cb_adjustment_value_changed (GtkAdjustment *adjustment,
-			    SheetWidgetAdjustment *swa)
+			     SheetWidgetAdjustment *swa)
 {
 	GnmCellRef ref;
 
@@ -767,14 +712,13 @@ cb_adjustment_value_changed (GtkAdjustment *adjustment,
 		/* TODO : add more control for precision, XL is stupid */
 		int new_val = gnm_fake_round (swa->adjustment->value);
 		if (cell->value != NULL &&
-		    cell->value->type == VALUE_INTEGER &&
-		    cell->value->v_int.val == new_val)
+		    VALUE_IS_FLOAT (cell->value) &&
+		    value_get_as_float (cell->value) == new_val)
 			return;
 
 		swa->being_updated = TRUE;
-		sheet_cell_set_value (cell, value_new_int (swa->adjustment->value));
+		sheet_cell_set_value (cell, value_new_int (new_val));
 
-		sheet_set_dirty (ref.sheet, TRUE);
 		workbook_recalc (ref.sheet->workbook);
 		sheet_update (ref.sheet);
 		swa->being_updated = FALSE;
@@ -787,13 +731,19 @@ sheet_widget_adjustment_init_full (SheetWidgetAdjustment *swa, GnmCellRef const
 	g_return_if_fail (swa != NULL);
 
 	swa->adjustment = GTK_ADJUSTMENT (gtk_adjustment_new (0., 0., 100., 1., 10., 0.));
+#if GLIB_CHECK_VERSION(2,10,0) && GTK_CHECK_VERSION(2,8,14)
+	g_object_ref_sink (swa->adjustment);
+#else
 	g_object_ref (swa->adjustment);
 	gtk_object_sink (GTK_OBJECT (swa->adjustment));
+#endif
 
 	swa->being_updated = FALSE;
 	swa->dep.sheet = NULL;
 	swa->dep.flags = adjustment_get_dep_type ();
-	swa->dep.expression = (ref != NULL) ? gnm_expr_new_cellref (ref) : NULL;
+	swa->dep.texpr = (ref != NULL)
+		? gnm_expr_top_new (gnm_expr_new_cellref (ref))
+		: NULL;
 	g_signal_connect (G_OBJECT (swa->adjustment),
 		"value_changed",
 		G_CALLBACK (cb_adjustment_value_changed), swa);
@@ -870,12 +820,12 @@ cb_adjustment_set_focus (GtkWidget *window, GtkWidget *focus_widget,
 	if (state->old_focus != NULL &&
 	    IS_GNM_EXPR_ENTRY (state->old_focus->parent)) {
 		GnmParsePos  pp;
-		GnmExpr const *expr = gnm_expr_entry_parse (
+		GnmExprTop const *texpr = gnm_expr_entry_parse (
 			GNM_EXPR_ENTRY (state->old_focus->parent),
 			parse_pos_init_sheet (&pp, state->sheet),
 			NULL, FALSE, GNM_EXPR_PARSE_DEFAULT);
-		if (expr != NULL)
-			gnm_expr_unref (expr);
+		if (texpr != NULL)
+			gnm_expr_top_unref (texpr);
 	}
 	state->old_focus = focus_widget;
 }
@@ -901,13 +851,13 @@ cb_adjustment_config_ok_clicked (GtkWidget *button, AdjustmentConfigState *state
 {
 	SheetObject *so = SHEET_OBJECT (state->swa);
 	GnmParsePos  pp;
-	GnmExpr const *expr = gnm_expr_entry_parse (state->expression,
+	GnmExprTop const *texpr = gnm_expr_entry_parse (state->expression,
 		parse_pos_init_sheet (&pp, so->sheet),
 		NULL, FALSE, GNM_EXPR_PARSE_DEFAULT);
-	if (expr != NULL) {
-		dependent_set_expr (&state->swa->dep, expr);
+	if (texpr != NULL) {
+		dependent_set_expr (&state->swa->dep, texpr);
 		dependent_link (&state->swa->dep);
-		gnm_expr_unref (expr);
+		gnm_expr_top_unref (texpr);
 	}
 
 	state->swa->adjustment->lower = gtk_spin_button_get_value_as_int (
@@ -934,7 +884,7 @@ static void
 sheet_widget_adjustment_user_config (SheetObject *so, SheetControl *sc)
 {
 	SheetWidgetAdjustment *swa = SHEET_WIDGET_ADJUSTMENT (so);
-	WorkbookControlGUI   *wbcg = scg_get_wbcg (SHEET_CONTROL_GUI (sc));
+	WorkbookControlGUI   *wbcg = scg_wbcg (SHEET_CONTROL_GUI (sc));
 	AdjustmentConfigState *state;
 	GtkWidget *table;
 
@@ -1047,22 +997,6 @@ sheet_widget_adjustment_write_xml_sax (SheetObject const *so, GsfXMLOut *output)
 	sax_write_dep (output, &swa->dep, "Input");
 }
 
-static gboolean
-sheet_widget_adjustment_write_xml_dom (SheetObject const     *so,
-				       XmlParseContext const *context,
-				       xmlNodePtr tree)
-{
-	SheetWidgetAdjustment *swa = SHEET_WIDGET_ADJUSTMENT (so);
-
-	xml_node_set_double (tree, "Min", swa->adjustment->lower, 2);
-	xml_node_set_double (tree, "Max", swa->adjustment->upper, 2); /* allow scrolling to max */
-	xml_node_set_double (tree, "Inc", swa->adjustment->step_increment, 2);
-	xml_node_set_double (tree, "Page", swa->adjustment->page_increment, 2);
-	xml_node_set_double  (tree, "Value", swa->adjustment->value, 2);
-	dom_write_dep (tree, &swa->dep, "Input");
-	return FALSE;
-}
-
 static gboolean
 sheet_widget_adjustment_read_xml_dom (SheetObject *so, char const *typename,
 				      XmlParseContext const *context,
@@ -1090,8 +1024,9 @@ sheet_widget_adjustment_read_xml_dom (SheetObject *so, char const *typename,
 }
 
 void
-sheet_widget_adjustment_set_details (SheetObject *so, GnmExpr const *link,
-				    int value, int min, int max, int inc, int page)
+sheet_widget_adjustment_set_details (SheetObject *so, GnmExprTop const *tlink,
+				     int value, int min, int max,
+				     int inc, int page)
 {
 	SheetWidgetAdjustment *swa = SHEET_WIDGET_ADJUSTMENT (so);
 	g_return_if_fail (swa != NULL);
@@ -1100,9 +1035,9 @@ sheet_widget_adjustment_set_details (SheetObject *so, GnmExpr const *link,
 	swa->adjustment->upper = max; /* allow scrolling to max */
 	swa->adjustment->step_increment = inc;
 	swa->adjustment->page_increment = page;
-	if (link != NULL) {
+	if (tlink != NULL) {
 		gboolean const linked = dependent_is_linked (&swa->dep);
-		dependent_set_expr (&swa->dep, link);
+		dependent_set_expr (&swa->dep, tlink);
 		if (linked)
 			dependent_link (&swa->dep);
 	} else
@@ -1122,7 +1057,6 @@ SOW_MAKE_TYPE (adjustment, Adjustment,
 	       &sheet_widget_adjustment_set_sheet,
 	       &sheet_widget_adjustment_clear_sheet,
 	       &sheet_widget_adjustment_copy,
-	       &sheet_widget_adjustment_write_xml_dom,
 	       &sheet_widget_adjustment_read_xml_dom,
 	       &sheet_widget_adjustment_write_xml_sax,
 	       NULL,
@@ -1331,8 +1265,8 @@ checkbox_eval (GnmDependent *dep)
 	GnmEvalPos pos;
 	gboolean err, result;
 
-	v = gnm_expr_eval (dep->expression, eval_pos_init_dep (&pos, dep),
-			   GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
+	v = gnm_expr_top_eval (dep->texpr, eval_pos_init_dep (&pos, dep),
+			       GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
 	result = value_get_as_bool (v, &err);
 	value_release (v);
 	if (!err) {
@@ -1364,7 +1298,9 @@ sheet_widget_checkbox_init_full (SheetWidgetCheckbox *swc,
 	swc->value = FALSE;
 	swc->dep.sheet = NULL;
 	swc->dep.flags = checkbox_get_dep_type ();
-	swc->dep.expression = (ref != NULL) ? gnm_expr_new_cellref (ref) : NULL;
+	swc->dep.texpr = (ref != NULL)
+		? gnm_expr_top_new (gnm_expr_new_cellref (ref))
+		: NULL;
 }
 
 static void
@@ -1380,14 +1316,12 @@ sheet_widget_checkbox_finalize (GObject *obj)
 
 	g_return_if_fail (swc != NULL);
 
-	if (swc->label != NULL) {
-		g_free (swc->label);
-		swc->label = NULL;
-	}
+	g_free (swc->label);
+	swc->label = NULL;
 
 	dependent_set_expr (&swc->dep, NULL);
 
-	(*sheet_object_widget_class->finalize) (obj);
+	sheet_object_widget_class->finalize (obj);
 }
 
 static GnmCellRef *
@@ -1397,10 +1331,10 @@ sheet_widget_checkbox_get_ref (SheetWidgetCheckbox const *swc,
 	GnmValue *target;
 	g_return_val_if_fail (swc != NULL, NULL);
 
-	if (swc->dep.expression == NULL)
+	if (swc->dep.texpr == NULL)
 		return NULL;
 
-	target = gnm_expr_get_range (swc->dep.expression);
+	target = gnm_expr_top_get_range (swc->dep.texpr);
 	if (target == NULL)
 		return NULL;
 
@@ -1426,7 +1360,6 @@ cb_checkbox_toggled (GtkToggleButton *button, SheetWidgetCheckbox *swc)
 		gboolean const new_val = gtk_toggle_button_get_active (button);
 		GnmCell *cell = sheet_cell_fetch (ref.sheet, ref.col, ref.row);
 		sheet_cell_set_value (cell, value_new_bool (new_val));
-		sheet_set_dirty (ref.sheet, TRUE);
 		workbook_recalc (ref.sheet->workbook);
 		sheet_update (ref.sheet);
 	}
@@ -1490,12 +1423,12 @@ cb_checkbox_set_focus (GtkWidget *window, GtkWidget *focus_widget,
 	if (state->old_focus != NULL &&
 	    IS_GNM_EXPR_ENTRY (state->old_focus->parent)) {
 		GnmParsePos  pp;
-		GnmExpr const *expr = gnm_expr_entry_parse (
+		GnmExprTop const *texpr = gnm_expr_entry_parse (
 			GNM_EXPR_ENTRY (state->old_focus->parent),
 			parse_pos_init_sheet (&pp, state->sheet),
 			NULL, FALSE, GNM_EXPR_PARSE_DEFAULT);
-		if (expr != NULL)
-			gnm_expr_unref (expr);
+		if (texpr != NULL)
+			gnm_expr_top_unref (texpr);
 	}
 	state->old_focus = focus_widget;
 }
@@ -1523,13 +1456,13 @@ cb_checkbox_config_ok_clicked (GtkWidget *button, CheckboxConfigState *state)
 {
 	SheetObject *so = SHEET_OBJECT (state->swc);
 	GnmParsePos  pp;
-	GnmExpr const *expr = gnm_expr_entry_parse (state->expression,
+	GnmExprTop const *texpr = gnm_expr_entry_parse (state->expression,
 		parse_pos_init_sheet (&pp, so->sheet),
 		NULL, FALSE, GNM_EXPR_PARSE_DEFAULT);
-	if (expr != NULL) {
-		dependent_set_expr (&state->swc->dep, expr);
+	if (texpr != NULL) {
+		dependent_set_expr (&state->swc->dep, texpr);
 		dependent_link (&state->swc->dep);
-		gnm_expr_unref (expr);
+		gnm_expr_top_unref (texpr);
 	}
 
 	gtk_widget_destroy (state->dialog);
@@ -1554,7 +1487,7 @@ static void
 sheet_widget_checkbox_user_config (SheetObject *so, SheetControl *sc)
 {
 	SheetWidgetCheckbox *swc = SHEET_WIDGET_CHECKBOX (so);
-	WorkbookControlGUI  *wbcg = scg_get_wbcg (SHEET_CONTROL_GUI (sc));
+	WorkbookControlGUI  *wbcg = scg_wbcg (SHEET_CONTROL_GUI (sc));
 	CheckboxConfigState *state;
 	GtkWidget *table;
 
@@ -1658,18 +1591,6 @@ sheet_widget_checkbox_write_xml_sax (SheetObject const *so, GsfXMLOut *output)
 	sax_write_dep (output, &swc->dep, "Input");
 }
 
-static gboolean
-sheet_widget_checkbox_write_xml_dom (SheetObject const 	   *so,
-				     XmlParseContext const *context,
-				     xmlNodePtr tree)
-{
-	SheetWidgetCheckbox *swc = SHEET_WIDGET_CHECKBOX (so);
-	xml_node_set_cstr (tree, "Label", swc->label);
-	xml_node_set_int  (tree, "Value", swc->value);
-	dom_write_dep (tree, &swc->dep, "Input");
-	return FALSE;
-}
-
 static gboolean
 sheet_widget_checkbox_read_xml_dom (SheetObject *so, char const *typename,
 				    XmlParseContext const *context,
@@ -1694,14 +1615,14 @@ sheet_widget_checkbox_read_xml_dom (SheetObject *so, char const *typename,
 }
 
 void
-sheet_widget_checkbox_set_link (SheetObject *so, GnmExpr const *expr)
+sheet_widget_checkbox_set_link (SheetObject *so, GnmExprTop const *texpr)
 {
 	SheetWidgetCheckbox *swc = SHEET_WIDGET_CHECKBOX (so);
 	gboolean const linked = dependent_is_linked (&swc->dep);
 
 	g_return_if_fail (swc != NULL);
 
-	dependent_set_expr (&swc->dep, expr);
+	dependent_set_expr (&swc->dep, texpr);
 	if (linked)
 		dependent_link (&swc->dep);
 }
@@ -1730,7 +1651,6 @@ SOW_MAKE_TYPE (checkbox, Checkbox,
 	       &sheet_widget_checkbox_set_sheet,
 	       &sheet_widget_checkbox_clear_sheet,
 	       &sheet_widget_checkbox_copy,
-	       &sheet_widget_checkbox_write_xml_dom,
 	       &sheet_widget_checkbox_read_xml_dom,
 	       &sheet_widget_checkbox_write_xml_sax,
 	       &sheet_widget_checkbox_get_property,
@@ -1791,12 +1711,11 @@ radio_button_eval (GnmDependent *dep)
 {
 	GnmValue *v;
 	GnmEvalPos pos;
-/*	gboolean err; */
-	int result;
+	gnm_float result;
 
-	v = gnm_expr_eval (dep->expression, eval_pos_init_dep (&pos, dep),
-			   GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
-	result = value_get_as_int (v);
+	v = gnm_expr_top_eval (dep->texpr, eval_pos_init_dep (&pos, dep),
+			       GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
+	result = value_get_as_float (v);
 	value_release (v);
 #if 0
 	if (!err) {
@@ -1824,7 +1743,7 @@ sheet_widget_radio_button_init (SheetObjectWidget *sow)
 
 	swrb->dep.sheet = NULL;
 	swrb->dep.flags = radio_button_get_dep_type ();
-	swrb->dep.expression = NULL;
+	swrb->dep.texpr = NULL;
 }
 
 static void
@@ -1832,10 +1751,8 @@ sheet_widget_radio_button_finalize (GObject *obj)
 {
 	SheetWidgetRadioButton *swrb = SHEET_WIDGET_RADIO_BUTTON (obj);
 
-	if (swrb->label != NULL) {
-		g_free (swrb->label);
-		swrb->label = NULL;
-	}
+	g_free (swrb->label);
+	swrb->label = NULL;
 
 	dependent_set_expr (&swrb->dep, NULL);
 	(*sheet_object_widget_class->finalize) (obj);
@@ -1961,7 +1878,6 @@ SOW_MAKE_TYPE (radio_button, RadioButton,
 	       NULL,
 	       NULL,
 	       NULL,
-	       NULL,
 	       &sheet_widget_radio_button_get_property,
 	       &sheet_widget_radio_button_set_property,
 	       {
@@ -1998,12 +1914,11 @@ list_content_eval (GnmDependent *dep)
 {
 	GnmValue *v;
 	GnmEvalPos pos;
-/*	gboolean err;*/
-	int result;
+	gnm_float result;
 
-	v = gnm_expr_eval (dep->expression, eval_pos_init_dep (&pos, dep),
-			   GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
-	result = value_get_as_int (v);
+	v = gnm_expr_top_eval (dep->texpr, eval_pos_init_dep (&pos, dep),
+			       GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
+	result = value_get_as_float (v);
 	value_release (v);
 #if 0
 	if (!err) {
@@ -2026,12 +1941,11 @@ list_output_eval (GnmDependent *dep)
 {
 	GnmValue *v;
 	GnmEvalPos pos;
-/*	gboolean err;*/
-	int result;
+	gnm_float result;
 
-	v = gnm_expr_eval (dep->expression, eval_pos_init_dep (&pos, dep),
-			   GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
-	result = value_get_as_int (v);
+	v = gnm_expr_top_eval (dep->texpr, eval_pos_init_dep (&pos, dep),
+			       GNM_EXPR_EVAL_SCALAR_NON_EMPTY);
+	result = value_get_as_float (v);
 	value_release (v);
 #if 0
 	if (!err) {
@@ -2059,11 +1973,11 @@ sheet_widget_list_base_init (SheetObjectWidget *sow)
 
 	swc->content_dep.sheet = NULL;
 	swc->content_dep.flags = list_content_get_dep_type ();
-	swc->content_dep.expression = NULL;
+	swc->content_dep.texpr = NULL;
 
 	swc->output_dep.sheet = NULL;
 	swc->output_dep.flags = list_output_get_dep_type ();
-	swc->output_dep.expression = NULL;
+	swc->output_dep.texpr = NULL;
 }
 
 static void
@@ -2113,17 +2027,6 @@ sheet_widget_list_base_write_xml_sax (SheetObject const *so, GsfXMLOut *output)
 	sax_write_dep (output, &swl->output_dep, "Output");
 }
 
-static gboolean
-sheet_widget_list_base_write_xml_dom (SheetObject const 	*so,
-				      XmlParseContext const *context,
-				      xmlNodePtr tree)
-{
-	SheetWidgetListBase *swl = SHEET_WIDGET_LIST_BASE (so);
-	dom_write_dep (tree, &swl->content_dep, "Content");
-	dom_write_dep (tree, &swl->output_dep, "Output");
-	return FALSE;
-}
-
 static gboolean
 sheet_widget_list_base_read_xml_dom (SheetObject *so, char const *typename,
 				     XmlParseContext const *context,
@@ -2152,7 +2055,6 @@ SOW_MAKE_TYPE (list_base, ListBase,
 	       &sheet_widget_list_base_set_sheet,
 	       &sheet_widget_list_base_clear_sheet,
 	       NULL,
-	       &sheet_widget_list_base_write_xml_dom,
 	       &sheet_widget_list_base_read_xml_dom,
 	       &sheet_widget_list_base_write_xml_sax,
 	       NULL,
