@@ -35,7 +35,6 @@ typedef struct _GODrawingAnchor {
 typedef enum {
 	SO_ANCHOR_UNKNOWN			= 0x00,
 	SO_ANCHOR_PERCENTAGE_FROM_COLROW_START	= 0x10,
-	SO_ANCHOR_PERCENTAGE_FROM_COLROW_END	= 0x11,
 
 	/* TODO : implement these */
 	SO_ANCHOR_PTS_FROM_COLROW_START		= 0x20,
@@ -71,7 +70,7 @@ GType sheet_object_exportable_get_type (void);
 
 gboolean      sheet_object_set_sheet	 (SheetObject *so, Sheet *sheet);
 Sheet	     *sheet_object_get_sheet	 (SheetObject const *so);
-gboolean      sheet_object_clear_sheet	 (SheetObject *so);
+void	      sheet_object_clear_sheet	 (SheetObject *so);
 
 SheetObject  *sheet_object_dup		 (SheetObject const *so);
 gboolean      sheet_object_can_print	 (SheetObject const *so);
@@ -108,7 +107,7 @@ void	sheet_objects_relocate   (GnmExprRelocateInfo const *rinfo, gboolean update
 				  GnmRelocUndo *undo);
 void    sheet_objects_clear      (Sheet const *sheet, GnmRange const *r, GType t);
 GSList *sheet_objects_get        (Sheet const *sheet, GnmRange const *r, GType t);
-void    sheet_object_clone_sheet (Sheet const *src, Sheet *dst, GnmRange *range);
+void    sheet_objects_dup	 (Sheet const *src, Sheet *dst, GnmRange *range);
 
 void     sheet_object_direction_set (SheetObject *so, gdouble const *coords);
 gboolean sheet_object_rubber_band_directly (SheetObject const *so);
